==> estateplat-common-1.2.3-20180918.005158-187-sources.jar: cn/gtmap/estateplat/model/exchange/national/QlfQlQtxgql.java <==
package cn.gtmap.estateplat.model.exchange.national;

import javax.xml.bind.annotation.XmlTransient;
import java.io.Serializable;
import java.util.Date;

/**
 * 其他相关权利
 * Created by xhc on 2015/11/20.
 */
public class QlfQlQtxgql implements Serializable {
    final static String ysdm = "6002029900";//要素代码
    private String bdcdyh;//不动产单元号
    private String ywh;//业务号
    private String qllx;//权利类型
    private String djlx;//登记类型
    private String djyy;//登记原因
    private Date qlqssj;//权利起始时间
    private Date qljssj;//权利结束时间
    private String qsfs;//取水方式
    private String sylx;//水源类型
    private Double qsl;//取水量
    private String qsyt;//取水用途
    private Double kcmj;//勘查面积
    private String kcfs;//开采方式
    private String kckz;//开采矿种
    private String scgm;//生产规模
    private String bdcqzh;//不动产权证号
    private String qxdm;//区县代码
    private String djjg;//登记机构
    private String dbr;//登簿人
    private Date djsj;//登记时间
    private String fj;//附记
    private byte[] ft;//附图
    private String qszt;//权属状态
    /**  插入更新时间
     * @author <a href="mailto:zhangqiang@gtmap.cn">zhangqiang</a>
     * @description
     */
    private Date updatetime;
    /**  插入创建时间
     * @author <a href="mailto:zhangqiang@gtmap.cn">zhangqiang</a>
     * @description
     */
    private Date createtime;
    @XmlTransient
    public Date getCreatetime() {
        return createtime;
    }

    public void setCreatetime(Date createtime) {
        this.createtime = createtime;
    }
    @XmlTransient
    public Date getUpdatetime() {
        return updatetime;
    }

    public void setUpdatetime(Date updatetime) {
        this.updatetime = updatetime;
    }

    public String getYsdm() {
        return ysdm;
    }


    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getDjyy() {
        return djyy;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public Date getQlqssj() {
        return qlqssj;
    }

    public void setQlqssj(Date qlqssj) {
        this.qlqssj = qlqssj;
    }

    public Date getQljssj() {
        return qljssj;
    }

    public void setQljssj(Date qljssj) {
        this.qljssj = qljssj;
    }

    public String getQsfs() {
        return qsfs;
    }

    public void setQsfs(String qsfs) {
        this.qsfs = qsfs;
    }

    public String getSylx() {
        return sylx;
    }

    public void setSylx(String sylx) {
        this.sylx = sylx;
    }

    public Double getQsl() {
        return qsl;
    }

    public void setQsl(Double qsl) {
        this.qsl = qsl;
    }

    public String getQsyt() {
        return qsyt;
    }

    public void setQsyt(String qsyt) {
        this.qsyt = qsyt;
    }

    public Double getKcmj() {
        return kcmj;
    }

    public void setKcmj(Double kcmj) {
        this.kcmj = kcmj;
    }

    public String getKcfs() {
        return kcfs;
    }

    public void setKcfs(String kcfs) {
        this.kcfs = kcfs;
    }

    public String getKckz() {
        return kckz;
    }

    public void setKckz(String kckz) {
        this.kckz = kckz;
    }

    public String getScgm() {
        return scgm;
    }

    public void setScgm(String scgm) {
        this.scgm = scgm;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public String getDjjg() {
        return djjg;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public byte[] getFt() {
        return ft;
    }

    public void setFt(byte[] ft) {
        this.ft = ft;
    }

    public String getQszt() {
        return qszt;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }
}

==> estateplat-common-1.2.4-20210914.120836-872-sources.jar: cn/gtmap/estateplat/model/exchange/national/QlfQlQtxgql.java <==
package cn.gtmap.estateplat.model.exchange.national;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import java.io.Serializable;
import java.util.Date;

/**
 * 其他相关权利
 * Created by xhc on 2015/11/20.
 */
public class QlfQlQtxgql implements Serializable {
    final static String ysdm = "6002029900";//要素代码
    private String bdcdyh;//不动产单元号
    private String ywh;//业务号
    private String qllx;//权利类型
    private String djlx;//登记类型
    private String djyy;//登记原因
    private Date qlqssj;//权利起始时间
    private Date qljssj;//权利结束时间
    private String qsfs;//取水方式
    private String sylx;//水源类型
    private Double qsl;//取水量
    private String qsyt;//取水用途
    private Double kcmj;//勘查面积
    private String kcfs;//开采方式
    private String kckz;//开采矿种
    private String scgm;//生产规模
    private String bdcqzh;//不动产权证号
    private String qxdm;//区县代码
    private String djjg;//登记机构
    private String dbr;//登簿人
    private Date djsj;//登记时间
    private String fj;//附记
    private byte[] ft;//附图
    private String qszt;//权属状态
    /**  插入更新时间
     * @author <a href="mailto:zhangqiang@gtmap.cn">zhangqiang</a>
     * @description
     */
    private Date updatetime;
    /**  插入创建时间
     * @author <a href="mailto:zhangqiang@gtmap.cn">zhangqiang</a>
     * @description
     */
    private Date createtime;

    private String ssywh;
    private String qlqx;
    @XmlAttribute(name = "SSYWH")
    public String getSsywh() {
        return ssywh;
    }

    public void setSsywh(String ssywh) {
        this.ssywh = ssywh;
    }
    @XmlAttribute(name = "QLQX")
    public String getQlqx() {
        return qlqx;
    }

    public void setQlqx(String qlqx) {
        this.qlqx = qlqx;
    }

    @XmlTransient
    public Date getCreatetime() {
        return createtime;
    }

    public void setCreatetime(Date createtime) {
        this.createtime = createtime;
    }
    @XmlTransient
    public Date getUpdatetime() {
        return updatetime;
    }

    public void setUpdatetime(Date updatetime) {
        this.updatetime = updatetime;
    }

    public String getYsdm() {
        return ysdm;
    }


    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getDjyy() {
        return djyy;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public Date getQlqssj() {
        return qlqssj;
    }

    public void setQlqssj(Date qlqssj) {
        this.qlqssj = qlqssj;
    }

    public Date getQljssj() {
        return qljssj;
    }

    public void setQljssj(Date qljssj) {
        this.qljssj = qljssj;
    }

    public String getQsfs() {
        return qsfs;
    }

    public void setQsfs(String qsfs) {
        this.qsfs = qsfs;
    }

    public String getSylx() {
        return sylx;
    }

    public void setSylx(String sylx) {
        this.sylx = sylx;
    }

    public Double getQsl() {
        return qsl;
    }

    public void setQsl(Double qsl) {
        this.qsl = qsl;
    }

    public String getQsyt() {
        return qsyt;
    }

    public void setQsyt(String qsyt) {
        this.qsyt = qsyt;
    }

    public Double getKcmj() {
        return kcmj;
    }

    public void setKcmj(Double kcmj) {
        this.kcmj = kcmj;
    }

    public String getKcfs() {
        return kcfs;
    }

    public void setKcfs(String kcfs) {
        this.kcfs = kcfs;
    }

    public String getKckz() {
        return kckz;
    }

    public void setKckz(String kckz) {
        this.kckz = kckz;
    }

    public String getScgm() {
        return scgm;
    }

    public void setScgm(String scgm) {
        this.scgm = scgm;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public String getDjjg() {
        return djjg;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public byte[] getFt() {
        return ft;
    }

    public void setFt(byte[] ft) {
        this.ft = ft;
    }

    public String getQszt() {
        return qszt;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }
}
